// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

// <-- JVM NOT MANDATORY -->

//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
//
// assert_equal --
//   Returns 1 if the two real matrices computed and expected are equal.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction


// Check for actual primes
assert_equal ( number_probableprime ( 7 ) , %t );
assert_equal ( number_probableprime ( 5 ) , %t );
assert_equal ( number_probableprime ( 5 , 3 ) , %t );
// Check for composite numbers
assert_equal ( number_probableprime ( 10 ) , %f );
assert_equal ( number_probableprime ( 20 ) , %f );
// Check for pseudo-primes : while pseudo prime does not detect that these numbers
// are composite, probable prime does it perfectly.
assert_equal ( number_probableprime ( 341 ) , %f );
assert_equal ( number_probableprime ( 561 ) , %f );
assert_equal ( number_probableprime ( 645 ) , %f );
assert_equal ( number_probableprime ( 1105 ) , %f );

// Test verbose
number_probableprime ( 10001 , [] , %t );


  // Test a few numbers
mprintf("Test a few numbers\n");
  integerlist  = [1  2  3  4  5  6  7  8  9  10 73 32003];
  expectedlist = [%f %t %t %f %t %f %t %f %f %f %t %t].';
  computed = [];
  for i=1:size(integerlist,"*")
    mprintf ( "Testing i=%s\n", string ( integerlist ( i ) ) )
    computed = number_probableprime ( integerlist ( i ) );
    expected = expectedlist ( i );
    assert_equal ( computed , expected );
  end
  // Test some even integers
mprintf("Test some even integers\n");
  integerlist = 2 * ( 2 : 50 );
  expected = %f;
  for i=1:size(integerlist,"*")
    mprintf ( "Testing i=%s\n", string ( integerlist ( i ) ) )
    computed = number_probableprime ( integerlist ( i ) );
    assert_equal ( computed , expected );
  end
  // Test some primes
mprintf("Test some primes\n");
  integerlist = [2,5,73,109,113,293,557,563,593,601,823,947,967];
  expected = %t;
  for i=1:size(integerlist,"*")
    mprintf ( "Testing i=%s\n", string ( integerlist ( i ) ) )
    computed = number_probableprime ( integerlist ( i ) );
    assert_equal ( computed , expected );
  end

// Check a large prime : too large for us...
//assert_equal ( number_probableprime ( 4432676798593 ) , %f );

